CascadingImpact class
Constructors
- CascadingImpact({required String dependencyName, required String requiredBy, required String currentConstraint, String? conflictReason})
-
const
Properties
- conflictReason → String?
-
final
- currentConstraint → String
-
final
- dependencyName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiredBy → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited