ApiUsageResult class

Constructors

ApiUsageResult({required String api, String? packageFilter, required int totalMatches, required List<ApiMatch> matches})
const

Properties

api String
final
hashCode int
The hash code for this object.
no setterinherited
matches List<ApiMatch>
final
packageFilter String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMatches int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited