BreakingChange class

Constructors

BreakingChange({required String id, required String description, required Severity severity, required ChangeCategory category, String? affectedApi, String? replacement, String? migrationGuide, String? sourceUrl, double confidence = 1.0})
const

Properties

affectedApi String?
final
category ChangeCategory
final
confidence double
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
migrationGuide String?
final
replacement String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity Severity
final
sourceUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited