CascadeResolver class

Resolves cascading dependency impacts for package upgrades.

Constructors

CascadeResolver(PubApiClient _pubApi, VersionResolver _versionResolver)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkCrossUpgradeConflicts(List<Map<String, String>> upgrades, PubspecData currentPubspec) Future<List<CascadingImpact>>
Check if multiple simultaneous upgrades have conflicts with each other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({required String packageName, required String targetVersion, required PubspecData currentPubspec}) Future<List<CascadingImpact>>
Check for cascading impacts of upgrading packageName to targetVersion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited