PubApiClient class

Constructors

PubApiClient({required CacheManager cacheManager, HttpClientWrapper? httpClient})
Creates a new pub.dev API client.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPackageInfo(String packageName) Future<Map<String, dynamic>>
Get full package info from pub.dev.
getPackageScore(String packageName) Future<Map<String, dynamic>?>
Get the package score and metrics from pub.dev.
getRepositoryUrl(String packageName) Future<String?>
Get the repository URL for a package from its latest pubspec.
getVersionInfo(String packageName, String version) Future<Map<String, dynamic>?>
Get detailed information for a specific version of a package.
getVersionPubspec(String packageName, String version) Future<Map<String, dynamic>?>
Get the pubspec for a specific version of a package.
getVersions(String packageName) Future<List<String>>
Get all published version strings for a package, sorted by publish order.
isVersionRetracted(String packageName, String version) Future<bool>
Check whether a specific version of a package has been retracted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited