PubspecParser class

Service that parses pubspec.yaml and pubspec.lock files from a Flutter/Dart project and produces strongly-typed PubspecData.

Constructors

PubspecParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String projectPath, {bool includeDevDependencies = true, bool includeTransitive = false}) Future<PubspecData>
Parse the pubspec.yaml (and optionally pubspec.lock) located under projectPath.
parseLockfile(File file) Future<LockfileData>
Parse a pubspec.lock file into a LockfileData model.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited