AnalyzeImpactTool class

Constructors

AnalyzeImpactTool({required PubspecParser pubspecParser, required PubApiClient pubApiClient, required GitHubClient githubClient, required FlutterDocsClient flutterDocsClient, required ChangelogParser changelogParser, required CodebaseAnalyzer codebaseAnalyzer, required VersionResolver versionResolver, required CascadeResolver cascadeResolver})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute({required String projectPath, required String packageName, required String targetVersion, String analysisDepth = 'file_level', bool includeCascading = true}) Future<Map<String, dynamic>>
Execute the analyze_upgrade_impact tool.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited