CheckUpgradesTool class

Constructors

CheckUpgradesTool(PubspecParser _parser, PubApiClient _pubApi, VersionResolver _versionResolver)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Map<String, dynamic> args) Future<Map<String, dynamic>>
Execute check_available_upgrades Input: projectPath, packageName?, includePrerelease?, targetFlutterVersion? Output: per-dependency upgrade info
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited