ScanProjectTool class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(Map<String, dynamic> args)
→ Future<Map<String, dynamic>>
-
Execute the scan_project tool
Input: projectPath, includeDevDependencies?, includeTransitive?
Output: project name, SDK constraints, dependency list with versions
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited