SearchApiUsageTool class

Constructors

SearchApiUsageTool(CodebaseAnalyzer _analyzer)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Map<String, dynamic> args) Future<Map<String, dynamic>>
Execute the search_api_usage tool Input: projectPath, apis (list of strings), packageFilter? Output: per-API match results with files, lines, types
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited