content property
The body text that belongs to this section (everything between this heading and the next heading at the same or higher level).
Implementation
final String content;
The body text that belongs to this section (everything between this heading and the next heading at the same or higher level).
final String content;