AnalysisResult class
Constructors
-
AnalysisResult({required String packageName, required String currentVersion, required String targetVersion, required RiskLevel riskLevel, required double riskScore, required int totalFilesAffected, required int totalLocationsAffected, required List<
BreakingChangeImpact> impacts, required List<CascadingImpact> cascadingImpacts, List<String> warnings = const [], double overallConfidence = 1.0}) -
const
Properties
-
cascadingImpacts
→ List<
CascadingImpact> -
final
- currentVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
impacts
→ List<
BreakingChangeImpact> -
final
- overallConfidence → double
-
final
- packageName → String
-
final
- riskLevel → RiskLevel
-
final
- riskScore → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetVersion → String
-
final
- totalFilesAffected → int
-
final
- totalLocationsAffected → int
-
final
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited