BreakingChangeImpact class
Constructors
-
BreakingChangeImpact({required BreakingChange breakingChange, required List<
CodeLocation> affectedLocations, String? suggestedFix}) -
const
Properties
-
affectedLocations
→ List<
CodeLocation> -
final
- breakingChange → BreakingChange
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedFix → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited