ChangelogEntry class
A single version entry parsed from a changelog.
Constructors
-
ChangelogEntry({required String version, String? date, required String content, required bool hasBreakingChanges, required List<
BreakingChange> breakingChanges, required List<String> changes}) -
const
Properties
-
breakingChanges
→ List<
BreakingChange> -
final
-
changes
→ List<
String> -
final
- content → String
-
final
- date → String?
-
final
- hasBreakingChanges → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited