ChangelogParser class
Parses raw CHANGELOG.md text into a list of ChangelogEntry objects.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEntriesBetween(
List< ChangelogEntry> entries, String fromVersion, String toVersion) → List<ChangelogEntry> -
Get entries between two versions (exclusive of
fromVersion, inclusive oftoVersion). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String changelogContent) → List< ChangelogEntry> - Parse a full CHANGELOG.md into structured entries.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited