content property

String content
final

The body text that belongs to this section (everything between this heading and the next heading at the same or higher level).

Implementation

final String content;